==> drools-wb-7.43.1.Final-project-sources.tar.gz: drools-wb-7.43.1.Final/drools-wb-screens/drools-wb-scenario-simulation-editor/drools-wb-scenario-simulation-editor-api/src/test/java/org/drools/workbench/screens/scenariosimulation/model/typedescriptor/PropertyTypeNameTest.java <==
/*
 * Copyright 2020 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.drools.workbench.screens.scenariosimulation.model.typedescriptor;

import org.junit.Test;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertNull;
import static org.junit.Assert.assertTrue;

public class PropertyTypeNameTest {

    @Test
    public void propertyTypeNameEmpty() {
        String typeName = "typeName";
        String baseTypeName = "baseTypeName";
        FactModelTree.PropertyTypeName propertyTypeNameTest = new FactModelTree.PropertyTypeName();
        assertNull(propertyTypeNameTest.getTypeName());
        assertFalse(propertyTypeNameTest.getBaseTypeName().isPresent());
        propertyTypeNameTest.setTypeName(typeName);
        assertEquals(typeName, propertyTypeNameTest.getPropertyTypeNameToVisualize());
        propertyTypeNameTest.setBaseTypeName(baseTypeName);
        assertTrue(propertyTypeNameTest.getBaseTypeName().isPresent());
        assertEquals(typeName, propertyTypeNameTest.getTypeName());
        assertEquals(baseTypeName, propertyTypeNameTest.getPropertyTypeNameToVisualize());
    }

    @Test
    public void propertyTypeNameNoBaseType() {
        String typeName = "typeName";
        FactModelTree.PropertyTypeName propertyTypeNameTest = new FactModelTree.PropertyTypeName(typeName);
        assertFalse(propertyTypeNameTest.getBaseTypeName().isPresent());
        assertEquals(typeName, propertyTypeNameTest.getTypeName());
        assertEquals(typeName, propertyTypeNameTest.getPropertyTypeNameToVisualize());
    }

    @Test
    public void propertyTypeNameWithBaseType() {
        String typeName = "typeName";
        String baseTypeName = "baseTypeName";
        FactModelTree.PropertyTypeName propertyTypeNameTest = new FactModelTree.PropertyTypeName(typeName, baseTypeName);
        assertTrue(propertyTypeNameTest.getBaseTypeName().isPresent());
        assertEquals(typeName, propertyTypeNameTest.getTypeName());
        assertEquals(baseTypeName, propertyTypeNameTest.getPropertyTypeNameToVisualize());
    }
}

==> drools-wb-7.69.0.Final-project-sources.tar.gz: drools-wb-7.69.0.Final/drools-wb-screens/drools-wb-scenario-simulation-editor/drools-wb-scenario-simulation-editor-api/src/test/java/org/drools/workbench/screens/scenariosimulation/model/typedescriptor/PropertyTypeNameTest.java <==
/*
 * Copyright 2020 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.drools.workbench.screens.scenariosimulation.model.typedescriptor;

import org.junit.Test;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertNull;
import static org.junit.Assert.assertTrue;

public class PropertyTypeNameTest {

    @Test
    public void propertyTypeNameEmpty() {
        String typeName = "typeName";
        String baseTypeName = "baseTypeName";
        FactModelTree.PropertyTypeName propertyTypeNameTest = new FactModelTree.PropertyTypeName();
        assertNull(propertyTypeNameTest.getTypeName());
        assertFalse(propertyTypeNameTest.getBaseTypeName().isPresent());
        propertyTypeNameTest.setTypeName(typeName);
        assertEquals(typeName, propertyTypeNameTest.getPropertyTypeNameToVisualize());
        propertyTypeNameTest.setBaseTypeName(baseTypeName);
        assertTrue(propertyTypeNameTest.getBaseTypeName().isPresent());
        assertEquals(typeName, propertyTypeNameTest.getTypeName());
        assertEquals(baseTypeName, propertyTypeNameTest.getPropertyTypeNameToVisualize());
    }

    @Test
    public void propertyTypeNameNoBaseType() {
        String typeName = "typeName";
        FactModelTree.PropertyTypeName propertyTypeNameTest = new FactModelTree.PropertyTypeName(typeName);
        assertFalse(propertyTypeNameTest.getBaseTypeName().isPresent());
        assertEquals(typeName, propertyTypeNameTest.getTypeName());
        assertEquals(typeName, propertyTypeNameTest.getPropertyTypeNameToVisualize());
    }

    @Test
    public void propertyTypeNestedNameNoBaseType() {
        String typeName = "typeName$nested";
        FactModelTree.PropertyTypeName propertyTypeNameTest = new FactModelTree.PropertyTypeName(typeName);
        assertFalse(propertyTypeNameTest.getBaseTypeName().isPresent());
        assertEquals(typeName, propertyTypeNameTest.getTypeName());
        assertEquals("typeName.nested", propertyTypeNameTest.getPropertyTypeNameToVisualize());
    }

    @Test
    public void propertyTypeNameWithBaseType() {
        String typeName = "typeName";
        String baseTypeName = "baseTypeName";
        FactModelTree.PropertyTypeName propertyTypeNameTest = new FactModelTree.PropertyTypeName(typeName, baseTypeName);
        assertTrue(propertyTypeNameTest.getBaseTypeName().isPresent());
        assertEquals(typeName, propertyTypeNameTest.getTypeName());
        assertEquals(baseTypeName, propertyTypeNameTest.getPropertyTypeNameToVisualize());
    }
}
